@@ -15,7 +15,7 @@
 #  limitations under the License.
 
 import sys
-from calculate.core.server.func import MethodsInterface
+from .func import MethodsInterface
 
 from calculate.lib.cl_lang import getLazyLocalTranslate, setLocalTranslate
 from calculate.lib.utils.common import getPagesInterval
