@@ -105,10 +105,10 @@ class VariableClBackupTime(ReadonlyVariable):
             hour = 60 * minute
             times = backup_diff.seconds
             if times >= hour:
-                ret.append(_("%d hours") % (times / hour))
+                ret.append(_("%d hours") % (times // hour))
                 times %= hour
             if times >= minute:
-                ret.append(_("%d minutes") % (times / minute))
+                ret.append(_("%d minutes") % (times // minute))
                 times %= minute
             if times:
                 ret.append(_("%d seconds") % times)
